@@ -1,6 +1,9 @@
 /// Configuration settings that can be adjusted and passed to a minification function to change the
 /// minification approach.
+#[derive(Default)]
 pub struct Cfg {
+    /// Do not minify DOCTYPEs. Minified DOCTYPEs may not be spec compliant.
+    pub do_not_minify_doctype: bool,
     /// Ensure all unquoted attribute values in the output do not contain any characters prohibited by the [WHATWG specification](https://html.spec.whatwg.org/multipage/syntax.html#attributes-2).
     pub ensure_spec_compliant_unquoted_attribute_values: bool,
     /// Do not omit closing tags when possible.
@@ -31,16 +34,15 @@ pub struct Cfg {
 
 impl Cfg {
     pub fn new() -> Cfg {
+        Cfg::default()
+    }
+
+    pub fn spec_compliant() -> Cfg {
         Cfg {
-            ensure_spec_compliant_unquoted_attribute_values: false,
-            keep_closing_tags: false,
-            keep_comments: false,
-            keep_html_and_head_opening_tags: false,
-            keep_spaces_between_attributes: false,
-            minify_css: false,
-            minify_js: false,
-            remove_bangs: false,
-            remove_processing_instructions: false,
+            do_not_minify_doctype: true,
+            ensure_spec_compliant_unquoted_attribute_values: true,
+            keep_spaces_between_attributes: true,
+            ..Cfg::default()
         }
     }
 }
