@@ -1,3 +1,6 @@
+use std::io::Write;
+
+use crate::ast::c14n::c14n_serialise_ast;
 pub use crate::cfg::Cfg;
 use crate::common::spec::tag::ns::Namespace;
 use crate::common::spec::tag::EMPTY_SLICE;
@@ -39,3 +42,12 @@ pub fn minify(src: &[u8], cfg: &Cfg) -> Vec<u8> {
     minify_content(cfg, &mut out, false, EMPTY_SLICE, parsed.children);
     out
 }
+
+pub fn canonicalise<T: Write>(out: &mut T, src: &[u8]) -> std::io::Result<()> {
+    let mut code = Code::new(src);
+    let parsed = parse_content(&mut code, Namespace::Html, EMPTY_SLICE, EMPTY_SLICE);
+    for c in parsed.children {
+        c14n_serialise_ast(out, &c)?;
+    }
+    Ok(())
+}
