@@ -9,6 +9,7 @@ use {
 };
 
 use crate::cfg::Cfg;
+use crate::common::whitespace::trimmed;
 
 #[cfg(feature = "js-esbuild")]
 lazy_static! {
@@ -27,13 +28,13 @@ lazy_static! {
 
 #[cfg(not(feature = "js-esbuild"))]
 pub fn minify_css(_cfg: &Cfg, out: &mut Vec<u8>, code: &[u8]) {
-    out.extend_from_slice(&code);
+    out.extend_from_slice(trimmed(code));
 }
 
 #[cfg(feature = "js-esbuild")]
 pub fn minify_css(cfg: &Cfg, out: &mut Vec<u8>, code: &[u8]) {
     if !cfg.minify_css {
-        out.extend_from_slice(&code);
+        out.extend_from_slice(trimmed(code));
     } else {
         minify_using_esbuild(out, code, &MINIFY_CSS_TRANSFORM_OPTIONS.clone());
     }
